==> react-native-sj-prime-base-0.0.26.tgz: package/src/app/(app)/settings.tsx <==
/* eslint-disable react/react-in-jsx-scope */
import { Env } from '@env';
import { useColorScheme } from 'nativewind';

import { Item } from '@/components/settings/item';
import { ItemsContainer } from '@/components/settings/items-container';
import { LanguageItem } from '@/components/settings/language-item';
import { ThemeItem } from '@/components/settings/theme-item';
import {
  colors,
  FocusAwareStatusBar,
  ScrollView,
  Text as RNText,
  View,
} from '@/components/ui';
import { Github, Rate, Share, Support, Website } from '@/components/ui/icons';
import { translate, useAuth } from '@/lib';
import TopNavigation from '@/library/top-navigation';
import Text from '@/library/text';
import Chip from '@/library/chip';
import TextButton from '@/library/text-button';
import { SearchIcon } from '@/library/icons/search-icon';

export default function Settings() {
  const signOut = useAuth.use.signOut();
  const { colorScheme } = useColorScheme();
  const iconColor =
    colorScheme === 'dark' ? colors.neutral[400] : colors.neutral[500];
  return (
    <>
      <TopNavigation backgroundColor="blue" barStyle={'light-content'}>
        <View className="flex-1 justify-center items-center bg-gray-200 gap-4">
          <TextButton
            variant="brand"
            size="medium"
            text="브랜드 버튼 (Medium)"
            onPress={() => {}}
          />
          <TextButton
            variant="brand"
            size="medium"
            text="브랜드 버튼 밑줄 (Medium)"
            underline
            onPress={() => {}}
          />
          <TextButton
            variant="brand"
            size="small"
            text="브랜드 버튼 (Small)"
            onPress={() => {}}
          />
          <TextButton
            variant="brand"
            size="small"
            text="브랜드 버튼 밑줄 (Small)"
            underline
            onPress={() => {}}
          />

          <TextButton
            variant="neutral"
            size="medium"
            text="기본 버튼 (Medium)"
            onPress={() => {}}
          />
          <TextButton
            variant="neutral"
            size="medium"
            text="기본 버튼 밑줄 (Medium)"
            underline
            onPress={() => {}}
          />
          <TextButton
            variant="neutral"
            size="small"
            text="기본 버튼 (Small)"
            onPress={() => {}}
          />
          <TextButton
            variant="neutral"
            size="small"
            text="기본 버튼 밑줄 (Small)"
            underline
            onPress={() => {}}
          />

          <TextButton
            variant="neutralLow"
            size="medium"
            text="중립 낮은강도 (Medium)"
            onPress={() => {}}
          />
          <TextButton
            variant="neutralLow"
            size="medium"
            text="중립 낮은강도 밑줄 (Medium)"
            underline
            onPress={() => {}}
          />
          <TextButton
            variant="neutralLow"
            size="small"
            text="중립 낮은강도 (Small)"
            onPress={() => {}}
          />
          <TextButton
            variant="neutralLow"
            size="small"
            text="중립 낮은강도 밑줄 (Small)"
            underline
            onPress={() => {}}
          />

          <TextButton
            variant="inverse"
            leftIcon={{ icon: <SearchIcon />, gap: 8 }}
            size="medium"
            text="반전 버튼 (Medium)"
            onPress={() => {}}
          />
          <TextButton
            variant="inverse"
            size="medium"
            text="반전 버튼 밑줄 (Medium)"
            underline
            onPress={() => {}}
          />
          <TextButton
            variant="inverse"
            size="small"
            text="반전 버튼 (Small)"
            onPress={() => {}}
          />
          <TextButton
            variant="inverse"
            size="small"
            text="반전 버튼 밑줄 (Small)"
            underline
            onPress={() => {}}
          />
        </View>
      </TopNavigation>
      {/* <TopNavigation backgroundColor="white" barStyle={'light-content'}>
        <ScrollView>
          <View className="flex-1 px-4 pt-16 ">
            <Text className="text-xl font-bold">
              {translate('settings.title')}
            </Text>
            <ItemsContainer title="settings.generale">
              <LanguageItem />
              <ThemeItem />
            </ItemsContainer>

            <ItemsContainer title="settings.about">
              <Item text="settings.app_name" value={Env.NAME} />
              <Item text="settings.version" value={Env.VERSION} />
            </ItemsContainer>

            <ItemsContainer title="settings.support_us">
              <Item
                text="settings.share"
                icon={<Share color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.rate"
                icon={<Rate color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.support"
                icon={<Support color={iconColor} />}
                onPress={() => {}}
              />
            </ItemsContainer>

            <ItemsContainer title="settings.links">
              <Item text="settings.privacy" onPress={() => {}} />
              <Item text="settings.terms" onPress={() => {}} />
              <Item
                text="settings.github"
                icon={<Github color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.website"
                icon={<Website color={iconColor} />}
                onPress={() => {}}
              />
            </ItemsContainer>

            <View className="my-8">
              <ItemsContainer>
                <Item text="settings.logout" onPress={signOut} />
              </ItemsContainer>
            </View>
          </View>
        </ScrollView>
      </TopNavigation> */}
    </>
  );
}

==> react-native-sj-prime-base-0.0.28.tgz: package/src/app/(app)/settings.tsx <==
/* eslint-disable react/react-in-jsx-scope */
import { Env } from '@env';
import { useColorScheme } from 'nativewind';

import { Item } from '@/components/settings/item';
import { ItemsContainer } from '@/components/settings/items-container';
import { LanguageItem } from '@/components/settings/language-item';
import { ThemeItem } from '@/components/settings/theme-item';
import {
  colors,
  FocusAwareStatusBar,
  ScrollView,
  Text as RNText,
  View,
} from '@/components/ui';
import { Github, Rate, Share, Support, Website } from '@/components/ui/icons';
import { translate, useAuth } from '@/lib';
import TopNavigation from '@/library/top-navigation';
import Text from '@/library/text';
import Chip from '@/library/chip';

export default function Settings() {
  const signOut = useAuth.use.signOut();
  const { colorScheme } = useColorScheme();
  const iconColor =
    colorScheme === 'dark' ? colors.neutral[400] : colors.neutral[500];
  return (
    <>
      <TopNavigation backgroundColor="blue" barStyle={'light-content'}>
        <View className="flex-1 justify-center items-center bg-gray-500 gap-2">
          <View className="flex-row gap-[6px]">
            <Chip
              variant={'staticWhite'}
              shape={'round'}
              text={'랜덤 추천'}
              size={'small'}
              onPress={() => {
                console.log('랜덤 추천');
              }}
            />
            <Chip
              variant={'staticWhite'}
              shape={'round'}
              text={'내 주변 여행지 찾기'}
              size={'small'}
              onPress={() => {
                console.log('내 주변 여행지 찾기');
              }}
            />
          </View>
          <Chip
            variant="outline"
            size="small"
            text="레이블"
            shape="round"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="outline"
            size="small"
            text="레이블"
            shape="round"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="neutralLow"
            size="small"
            text="레이블"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="staticWhite"
            size="small"
            text="레이블"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="outline"
            size="medium"
            text="레이블"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="neutralLow"
            size="medium"
            text="레이블"
            onPress={() => console.log('pressed')}
          />
          <Chip
            variant="staticWhite"
            size="medium"
            text="레이블"
            onPress={() => console.log('pressed')}
          />
        </View>
      </TopNavigation>
      {/* <TopNavigation backgroundColor="white" barStyle={'light-content'}>
        <ScrollView>
          <View className="flex-1 px-4 pt-16 ">
            <Text className="text-xl font-bold">
              {translate('settings.title')}
            </Text>
            <ItemsContainer title="settings.generale">
              <LanguageItem />
              <ThemeItem />
            </ItemsContainer>

            <ItemsContainer title="settings.about">
              <Item text="settings.app_name" value={Env.NAME} />
              <Item text="settings.version" value={Env.VERSION} />
            </ItemsContainer>

            <ItemsContainer title="settings.support_us">
              <Item
                text="settings.share"
                icon={<Share color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.rate"
                icon={<Rate color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.support"
                icon={<Support color={iconColor} />}
                onPress={() => {}}
              />
            </ItemsContainer>

            <ItemsContainer title="settings.links">
              <Item text="settings.privacy" onPress={() => {}} />
              <Item text="settings.terms" onPress={() => {}} />
              <Item
                text="settings.github"
                icon={<Github color={iconColor} />}
                onPress={() => {}}
              />
              <Item
                text="settings.website"
                icon={<Website color={iconColor} />}
                onPress={() => {}}
              />
            </ItemsContainer>

            <View className="my-8">
              <ItemsContainer>
                <Item text="settings.logout" onPress={signOut} />
              </ItemsContainer>
            </View>
          </View>
        </ScrollView>
      </TopNavigation> */}
    </>
  );
}
